#ifndef _PIECE_PAIR_DIALOG_H
#define _PIECE_PAIR_DIALOG_H

#include <qdialog.h>
#include "osl/state/numEffectState.h"

class PiecePair;

class PiecePairDialog : public QDialog
{
public:
  PiecePairDialog(const osl::state::NumEffectState &state,
		  QWidget *parent = 0, const char *name = 0);
};

#endif // _PIECE_PAIR_DIALOG_H
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
